package com.tiqiaa.tclfp;

import com.tiqiaa.tclfp.Brand;
import com.tiqiaa.tclfp.DeviceType;
import com.tiqiaa.tclfp.IIrDAServiceCallback;

/**
* IrDA 服务接口
*/
interface IIrDAService {
	void registerCallback(IIrDAServiceCallback callback);
	void unregisterCallback(IIrDAServiceCallback callback);

	/**
	* 获取电器类型列表
	*/
	DeviceType[] getDeviceType();

	/**
	* 获取指定电器类型下的品牌列表
	* @param deviceType 电器类型编号
	* @see MachineType
	*/
	Brand[] getDeviceBrand(int deviceType);

	/**
	* 创建遥控器
	*/
	void createDevice();

	/**
	* 获取电视节目信号
	* @param channel_id 频道ID
	* @see ChannelInfo
	*/
	void getProgramInfo(int channel_id);

	/**
	* 获取服务版本号
	* @return 服务版本号
	* @see Constants#CURRENT_SERVICE_VERSION
	*/
	int getServiceVersion();
	
	/**
	* 获取IrDA APK版本
	* @return versionCode and versionName
	*/
	String[] getAPKVersion();

	/**
	* 在指定房间中创建遥控器
	* @param roomNumber 房间号
	*/
	void createDeviceInRoom(int roomNumber);	
}
